package com.xkrs.utilsnew;

import com.xkrs.model.bean.AddressBean;
import com.xkrs.model.vo.GaoDeIgGeocodeVo;
import com.xkrs.utilsold.GaoDeApiUtil;
import org.apache.hc.core5.util.TextUtils;

import java.util.ArrayList;
import java.util.List;

public class FirePointAddressUtils {

    private FirePointAddressUtils() {
    }

    /**
     * 使用网络方式解析地址信息
     */
    public static AddressBean analysisWithNetwork(double longitude, double latitude) {
        try {
            List<String> locationList = new ArrayList<>();
            locationList.add(longitude + "," + latitude);
            GaoDeIgGeocodeVo geocode = GaoDeApiUtil.geocode(locationList);
            GaoDeIgGeocodeVo.Regeocode reGeoCode = geocode.getRegeocodes().get(0);
            GaoDeIgGeocodeVo.AddressComponent addressComponent = reGeoCode.getAddressComponent().get(0);
            String townCode = addressComponent.getTowncode();
            //填充AddressBean数据
            AddressBean addressBean = new AddressBean();
            addressBean.setSuccess(true);
            addressBean.setProCode(townCode.substring(0, 2) + "0000");
            addressBean.setProName(addressComponent.getProvince());
            addressBean.setCityCode(townCode.substring(0, 4) + "00");
            addressBean.setCityName(addressComponent.getCity());
            addressBean.setCountyCode(townCode.substring(0, 6));
            addressBean.setCountyName(addressComponent.getDistrict());
            addressBean.setTownCode(townCode.substring(0, 9));
            addressBean.setTownName(addressComponent.getTownship());
            addressBean.setFirePointAddress(reGeoCode.getFormatted_address());
            //检查AddressBean的合法性
            checkValidAddress(addressBean);
            return addressBean;
        } catch (Exception e) {
            e.printStackTrace();
        }
        AddressBean addressBean = new AddressBean();
        addressBean.setSuccess(false);
        return addressBean;
    }

    /**
     * 检查AddressBean的合法性
     */
    private static void checkValidAddress(AddressBean addressBean) {
        if (addressBean.getProCode().length() != 6) {
            throw new RuntimeException("ProCode Error");
        }
        if (TextUtils.isEmpty(addressBean.getProName())) {
            throw new RuntimeException("ProName Error");
        }
        if (addressBean.getCityCode().length() != 6) {
            throw new RuntimeException("CityCode Error");
        }
        if (TextUtils.isEmpty(addressBean.getCityName())) {
            throw new RuntimeException("CityName Error");
        }
        if (addressBean.getCountyCode().length() != 6) {
            throw new RuntimeException("CountyCode Error");
        }
        if (TextUtils.isEmpty(addressBean.getCountyName())) {
            throw new RuntimeException("CountyName Error");
        }
        if (addressBean.getTownCode().length() != 9) {
            throw new RuntimeException("TownCode Error");
        }
        if (TextUtils.isEmpty(addressBean.getTownName())) {
            throw new RuntimeException("TownName Error");
        }
        if (TextUtils.isEmpty(addressBean.getFirePointAddress())) {
            throw new RuntimeException("FirePointAddress Error");
        }
    }

    public static void main(String[] args) {

        AddressBean addressBean = analysisWithNetwork(120, 36);
        System.out.println(addressBean.toString());
    }
}
